@@ -73,23 +73,15 @@ def convert_from_gk25(north, east):
     pnt.transform(coord_transform)
     return pnt
 '''
+
+
 def convert_from_gk23(north, east):
-    ps = "POINT (%f %f)" % (east, north)
-    #g = gdal.OGRGeometry(ps, GK23_SRS)
-    #if coord_transform:
-    #    g.transform(coord_transform)
-    #return g
-    pnt = Point(north, east, srid=3877)
-    #pnt.transform(coord_transform)
-    gps_srs = SpatialReference(3067) #EPSG:3877 is gk_23 
+    pnt = Point(east, north, srid=3877) # First we make our data into a POINT
+    gps_srs = SpatialReference(3877) #EPSG:3877 is gk_23 
     target_sourc = SpatialReference(4326)
     pnt.transform(CoordTransform(gps_srs, target_sourc))
-
     return pnt
-    #if PROJECTION_SRID == GK23_SRID:
-    #    return pnt
-    #pnt.transform(coord_transform)
-    #return pnt
+
 
 def poly_diff(p1, p2):
     # Make sure we calculate the area with a 2d coordinate system
@@ -374,8 +366,8 @@ class TurkuImporter(Importer):
                     try:
                         can_continue = True
                         if not line[0] or not line[1] or not line[2] or not line[3] or not line[4]:
+                            #print("CAN'T PARSE FOLLOWING ADDRESS DATA... skipping:", line)
                             can_continue = False
-
                         if can_continue == True:
                             dkt = dict({int(line[3] + line[4]): {
                                     'kaupunki': line[0],
@@ -451,6 +443,8 @@ class TurkuImporter(Importer):
                 except:
                     pass
 
+            #print("Done!")
+
         # Read FINAL parsed CSV.
         #with open(newaddressFilePath,'r', encoding='ISO-8859-1') as csvfile:
         #    csvreader = csv.reader(csvfile)
@@ -551,20 +545,40 @@ class TurkuImporter(Importer):
                 coord_n = str(feat.get('n'))
                 coord_e = str(feat.get('e'))
 
+
+            
+                #new_n = list(coord_n)
+                #new_n[6] += "."
+                #new_n = "".join(new_n)
+                #new_e = list(coord_e)
+                #new_e[1] += "."
+                #new_e = "".join(new_e)
+
+                #coord_n = float(new_n)
+                #coord_e = float(new_e)
+
+
+
+                coord_n = str(feat.get('n'))
+                coord_e = str(feat.get('e'))
+
                 new_n = list(coord_n)
-                new_n[6] += "."
+                new_n[6] += ".00"
+                
                 new_n = "".join(new_n)
                 new_e = list(coord_e)
-                new_e[1] += "."
+                new_e[7] += ".00"
                 new_e = "".join(new_e)
 
                 coord_n = float(new_n)
                 coord_e = float(new_e)
 
+                #print(coord_n, coord_e)
+
                 # muni_name = feat.get('kaupunki')
                 muni = muni_dict[muni_name]
                 street = muni.streets_by_name.get(street_name, None)
-                                
+                #print(street.name_fi)
                 if not street:
                     self.logger.info("street {} not found in DB, creating it".format(street_name))
                     street = Street(name_fi=street_name, name=street_name, municipality=muni)
@@ -585,10 +599,13 @@ class TurkuImporter(Importer):
                 # This must be ETRS-GK23 because this is Turku area and it will be back to ETRS-FIN35.
                 addr_id = make_addr_id(num, num2, letter)
                 addr = street.addrs.get(addr_id, None)
-                location = convert_from_gk23(coord_n, coord_e )# Old code conversion uses ETRS-GK25 (Helsinki region). NOTE! Check the result
+                location = convert_from_gk23(coord_n, coord_e)# Old code conversion uses ETRS-GK25 (Helsinki region). NOTE! Check the result
                 #addr.location = location.wkb
+                addr.location = location
+                addr.save()
                 #print("New addr.location... ", addr.location)
                 #addr.save() # force save address...
+                #print(street, addr, location)
                 if not addr:
                     #print("NO ADDRESS!")
                     self.logger.debug("Street {} did not have address {}. Creating".format(street.name, addr_id))
